==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/Q1ExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { Q1ExpressionDescription } from "./Q1ExpressionDescription";
/**
 * @hidden
 */
var Q1ExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Q1ExpressionDescriptionMetadata, _super);
    function Q1ExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Q1ExpressionDescriptionMetadata.b = function (a) {
        if (Q1ExpressionDescriptionMetadata.a == null) {
            Q1ExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            Q1ExpressionDescriptionMetadata.c(Q1ExpressionDescriptionMetadata.a);
        }
        if (a.j(Q1ExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(Q1ExpressionDescriptionMetadata.a);
    };
    Q1ExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    Q1ExpressionDescriptionMetadata.d = function (a) {
        Q1ExpressionDescriptionMetadata.b(a);
        a.aa("Q1Expression", function () { return new Q1ExpressionDescription(); });
        a.z("Q1Expression", Q1ExpressionDescriptionMetadata.a);
    };
    Q1ExpressionDescriptionMetadata.$t = markType(Q1ExpressionDescriptionMetadata, 'Q1ExpressionDescriptionMetadata');
    Q1ExpressionDescriptionMetadata.a = null;
    return Q1ExpressionDescriptionMetadata;
}(Base));
export { Q1ExpressionDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/Q1ExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { Q1ExpressionDescription } from "./Q1ExpressionDescription";
/**
 * @hidden
 */
var Q1ExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Q1ExpressionDescriptionMetadata, _super);
    function Q1ExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Q1ExpressionDescriptionMetadata.b = function (a) {
        if (Q1ExpressionDescriptionMetadata.a == null) {
            Q1ExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            Q1ExpressionDescriptionMetadata.c(Q1ExpressionDescriptionMetadata.a);
        }
        if (a.k(Q1ExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(Q1ExpressionDescriptionMetadata.a);
    };
    Q1ExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    Q1ExpressionDescriptionMetadata.d = function (a) {
        Q1ExpressionDescriptionMetadata.b(a);
        a.ac("Q1Expression", function () { return new Q1ExpressionDescription(); });
        a.ab("Q1Expression", Q1ExpressionDescriptionMetadata.a);
    };
    Q1ExpressionDescriptionMetadata.$t = markType(Q1ExpressionDescriptionMetadata, 'Q1ExpressionDescriptionMetadata');
    Q1ExpressionDescriptionMetadata.a = null;
    return Q1ExpressionDescriptionMetadata;
}(Base));
export { Q1ExpressionDescriptionMetadata };
